@@ -3,3 +3,5 @@ from .img import *
 from .nn import *
 from .imgen import *
 from .viz import *
+from .graphx import *
+from .preproc import *
