@@ -64,8 +64,21 @@ def get_nn_distances_(coordinates: np.ndarray, nn: int = 2,
     return d[:, 1:], coordinates[nn]
 
 
+def imcoordgrid(im_dim: Tuple) -> torch.Tensor:
+    """
+    Returns a grid with pixel coordinates (used e.g. in rVAE)
+    """
+    xx = torch.linspace(-1, 1, im_dim[0])
+    yy = torch.linspace(1, -1, im_dim[1])
+    x0, x1 = torch.meshgrid(xx, yy)
+    x_coord = torch.stack(
+        [x0.T.flatten(), x1.T.flatten()], axis=1)
+    return x_coord
+
+
 def transform_coordinates(coord: Union[np.ndarray, torch.Tensor],
-                          phi: float, coord_dx: Union[np.ndarray, torch.Tensor]
+                          phi: float,
+                          coord_dx: Union[np.ndarray, torch.Tensor, int] = 0,
                           ) -> torch.Tensor:
     """
     Pytorch-based 2D rotation of coordinates followed by translation.
@@ -189,7 +202,7 @@ def peak_refinement(imgdata: np.ndarray, coordinates: np.ndarray,
             x, y = np.mgrid[:e1:1, :e2:1]
             initial_guess = (img[d, d], d, d, 1, 1, 0, 0)
             try:
-                popt, pcov = optimize.curve_fit(
+                popt, _ = optimize.curve_fit(
                         gaussian_2d, (x, y), img.flatten(), p0=initial_guess)
                 if np.linalg.norm(popt[1:3] - d) < 3:
                     xyc = popt[1:3] + np.around(c) - d
