@@ -2,161 +2,19 @@
 img.py
 ======
 
-Helper functions for working with images. Includes image pre- and post-processing
-for model training and prediction and generation of stack of subimages
+Helper functions for working with images.
 
 Created by Maxim Ziatdinov (email: maxim.ziatdinov@ai4microscopy.com)
 """
 
 from typing import Tuple, Optional, Dict, Union, List
 from collections import OrderedDict
-import warnings
 import numpy as np
 import cv2
 from scipy import fftpack, ndimage
 from sklearn.feature_extraction.image import extract_patches_2d
-import torch
 from .coords import remove_edge_coord
 
-input_data_types = Union[np.ndarray, List[np.ndarray], Dict[int, np.ndarray]]
-
-
-def preprocess_training_data(images_all: input_data_types,
-                             labels_all: input_data_types,
-                             images_test_all: input_data_types,
-                             labels_test_all: input_data_types,
-                             batch_size: int) -> Tuple[List[np.ndarray]]:
-    """
-    Preprocess training and test data
-
-    Args:
-        images_all (list / dict / 4D numpy array):
-            List or dictionary of 4D numpy arrays or 4D numpy array
-            (3D image tensors stacked along the first dim)
-            representing training images
-        labels_all (list / dict / 4D numpy array):
-            List or dictionary of 3D numpy arrays or
-            4D (binary) / 3D (multiclass) numpy array
-            where 3D / 2D image are tensors stacked along the first dim
-            which represent training labels (aka masks aka ground truth)
-        images_test_all (list / dict / 4D numpy array):
-            List or dictionary of 4D numpy arrays or 4D numpy array
-            (3D image tensors stacked along the first dim)
-            representing test images
-        labels_test_all (list / dict / 4D numpy array):
-            List or dictionary of 3D numpy arrays or
-            4D (binary) / 3D (multiclass) numpy array
-            where 3D / 2D image are tensors stacked along the first dim
-            which represent test labels (aka masks aka ground truth)
-        batch_size (int):
-            Size of training and test batches
-
-    Returns:
-        4 lists processed with preprocessed training and test data,
-        number of classes inferred from the data
-    """
-    if not (type(images_all) == type(labels_all) ==
-            type(images_test_all) == type(labels_test_all)):
-        raise AssertionError(
-            "Provide all training and test data in the same format")
-    if isinstance(labels_all, list):
-        pass
-    elif isinstance(labels_all, dict):
-        images_all = [i for i in images_all.values()]
-        labels_all = [i for i in labels_all.values()]
-        images_test_all = [i for i in images_test_all.values()]
-        labels_test_all = [i for i in labels_test_all.values()]
-    elif isinstance(labels_all, np.ndarray):
-        n_train_batches, _ = np.divmod(labels_all.shape[0], batch_size)
-        n_test_batches, _ = np.divmod(labels_test_all.shape[0], batch_size)
-        images_all = np.split(
-            images_all[:n_train_batches*batch_size], n_train_batches)
-        labels_all = np.split(
-            labels_all[:n_train_batches*batch_size], n_train_batches)
-        images_test_all = np.split(
-            images_test_all[:n_test_batches*batch_size], n_test_batches)
-        labels_test_all = np.split(
-            labels_test_all[:n_test_batches*batch_size], n_test_batches)
-    else:
-        raise NotImplementedError(
-            "Provide training and test data as python list (or dictionary)",
-            "of numpy arrays or as 4D (images)",
-            "and 4D/3D (labels for single/multi class) numpy arrays"
-        )
-    num_classes = max(set([len(np.unique(lab)) for lab in labels_all]))
-    if num_classes == 1:
-        raise AssertionError(
-            "Confirm that you have a class corresponding to background")
-    num_classes = num_classes - 1 if num_classes == 2 else num_classes
-
-    imshapes_train = set([len(im.shape) for im in images_all])
-    if len(imshapes_train) != 1:
-        raise AssertionError(
-            "All training images must have the same dimensionality")
-    imshapes_test = set([len(im.shape) for im in images_test_all])
-    if len(imshapes_test) != 1:
-        raise AssertionError(
-            "All test images must have the same dimensionality")
-    if imshapes_train.pop() == 3:
-        warnings.warn(
-            'Adding a channel dimension of 1 to training images',
-            UserWarning
-        )
-        images_all_e = [
-            np.expand_dims(im, axis=1) for im in images_all]
-        images_all = images_all_e
-    if imshapes_test.pop() == 3:
-        warnings.warn(
-            'Adding a channel dimension of 1 to test images',
-            UserWarning
-        )
-        images_test_all_e = [
-            np.expand_dims(im, axis=1) for im in images_test_all]
-        images_test_all = images_test_all_e
-
-    lshapes_train = set([len(l.shape) for l in labels_all])
-    if len(lshapes_train) != 1:
-        raise AssertionError(
-         "All labels must have the same dimensionality")
-    lshapes_test = set([len(l.shape) for l in labels_test_all])
-    if len(lshapes_test) != 1:
-        raise AssertionError(
-            "All labels must have the same dimensionality")
-    if num_classes == 1 and lshapes_train.pop() == 3:
-        warnings.warn(
-            'Adding a channel dimension of 1 to training labels',
-            UserWarning
-        )
-        labels_all_e = [
-            np.expand_dims(l, axis=1) for l in labels_all]
-        labels_all = labels_all_e
-    if num_classes == 1 and lshapes_test.pop() == 3:
-        warnings.warn(
-            'Adding a channel dimension of 1 to test labels',
-            UserWarning
-        )
-        labels_test_all_e = [
-            np.expand_dims(l, axis=1) for l in labels_test_all]
-        labels_test_all = labels_test_all_e
-    return (images_all, labels_all,
-            images_test_all, labels_test_all,
-            num_classes)
-
-
-def torch_format(image_data: np.ndarray) -> torch.Tensor:
-    """
-    Reshapes, normalizes and converts image data
-    to pytorch format for model training and prediction
-
-    Args:
-        image_data (3D numpy array):
-            Image stack with dimensions (n_batches x height x width)
-    """
-    image_data = np.expand_dims(image_data, axis=1)
-    image_data = (image_data - np.amin(image_data))/np.ptp(image_data)
-    image_data = torch.from_numpy(image_data).float()
-    return image_data
-
 
 def img_resize(image_data: np.ndarray, rs: Tuple[int],
                round_: bool = False) -> np.ndarray:
@@ -726,4 +584,3 @@ def get_blob_params(nn_output: np.ndarray, im_thresh: float,
         dictionary['angles'] = angles
         blob_dict[i] = dictionary
     return blob_dict
-
